@@ -101,6 +101,7 @@ class Bot(GroupMixin, Client):
     def __init__(self, command_prefix: Any, auth: Auth, *,
                  description: Optional[str] = None,
                  **kwargs: Any) -> None:
+        kwargs['case_insensitive'] = kwargs.get('case_insensitive', False)
         super().__init__(auth, **kwargs)
 
         self.command_prefix = command_prefix
@@ -122,9 +123,12 @@ class Bot(GroupMixin, Client):
         self.__extensions = {}
         self._checks = []
         self._check_once = []
+
         self._before_invoke = None
         self._after_invoke = None
 
+
+
         self.add_event_handler('friend_message', self.process_commands)
         self.add_event_handler('party_message', self.process_commands)
 
@@ -133,11 +137,12 @@ class Bot(GroupMixin, Client):
             if isinstance(obj, _BaseCommand):
                 obj.instance = self
 
-                try:
-                    self.add_command(obj)
-                except CommandError:
-                    traceback.print_exc()
-                    continue
+                if obj.parent is None:
+                    try:
+                        self.add_command(obj)
+                    except CommandError:
+                        traceback.print_exc()
+                        continue
 
         super().register_methods()
 
@@ -145,7 +150,10 @@ class Bot(GroupMixin, Client):
                     close_http: bool = True,
                     dispatch_close: bool = True) -> None:
         if dispatch_close:
-            await self.dispatch_and_wait_event('close')
+            await asyncio.gather(
+                self.dispatch_and_wait_event('before_close'),
+                self.dispatch_and_wait_event('close'),
+            )
 
         for extension in tuple(self.__extensions):
             try:
@@ -399,7 +407,7 @@ class Bot(GroupMixin, Client):
         if cog is None:
             return
 
-      
+
 
         cog._eject(self)
 
@@ -769,7 +777,6 @@ class Bot(GroupMixin, Client):
         while pending:
             done, pending = await asyncio.wait(
                 pending,
-                loop=self.loop,
                 return_when=asyncio.FIRST_COMPLETED,
                 timeout=timeout
             )
@@ -792,13 +799,13 @@ class Bot(GroupMixin, Client):
             self._print_error(ctx, error)
 
     def dispatch_error(self, ctx: Context, error: Exception) -> None:
-        if self._event_has_handlers('command_error'):
+        if self._event_has_handler('command_error'):
             futures = self.dispatch_event('command_error', ctx, error)
             asyncio.ensure_future(self._wait_for_error_return(
                 futures,
                 ctx,
                 error
-            ), loop=self.loop)
+            ))
         else:
             self._print_error(ctx, error)
 
